@@ -46,7 +46,7 @@
 
 // The datestamp of the C++ library in compressed ISO date format.
 #undef __GLIBCXX__ /* The testsuite defines it to 99999999 to block PCH.  */
-#define __GLIBCXX__ 20250808
+#define __GLIBCXX__ 20251122
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1163,7 +1163,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_HAVE_LDEXPL 1
 
 /* Define to 1 if you have the <libintl.h> header file. */
-#define _GLIBCXX_HAVE_LIBINTL_H 1
+/* #undef _GLIBCXX_HAVE_LIBINTL_H */
 
 /* Only used in build directory testsuite_hooks.h. */
 #define _GLIBCXX_HAVE_LIMIT_AS 1
@@ -1799,7 +1799,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_USE_NANOSLEEP 1
 
 /* Define if NLS translations are to be used. */
-#define _GLIBCXX_USE_NLS 1
+/* #undef _GLIBCXX_USE_NLS */
 
 /* Define if nl_langinfo_l should be used for std::text_encoding. */
 #define _GLIBCXX_USE_NL_LANGINFO_L 1
